<?php
// Version: SMF 2.0 RC1; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '2.0 Beta 4 Public';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status separate from topic icons? */
	$settings['separate_sticky_lock'] = true;

	/* Does this theme use the strict doctype? */
	$settings['strict_doctype'] = false;

	/* Does this theme use post previews on the message index? */
	$settings['message_index_preview'] = false;
}

// The main sub template above the content.
function template_html_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />
	<meta name="keywords" content="SMF, , , , , , , smf, , " />
	<meta name="verify-v1" content="52t1TsMiCuaOFW48eXmXiANYhNUlqXa3WTsPwHYCwp4=" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/script.js?b21"></script>
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/theme.js?b21"></script>
	<!--[if lt IE 7]>
		<script defer type="text/javascript" src="', $settings['default_theme_url'], '/scripts/pngfix.js"></script>
		<![endif]-->
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_default_theme_url = "', $settings['default_theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '
		if (confirm("' . $txt['show_personal_messages'] . '"))
			window.open("' . $scripturl . '?action=pm");' : '', '
		var ajax_notification_text = "', $txt['ajax_in_progress'], '";
		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="index, follow" />';

	// The ?b21 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?b21" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/print.css?b21" media="print" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		// Create the main header object.
		var mainHeader = new smfToggle("upshrink", ', empty($options['collapse_header']) ? 'false' : 'true', ');
		mainHeader.useCookie(', $context['user']['is_guest'] ? 1 : 0, ');
		mainHeader.setOptions("collapse_header", "', $context['session_id'], '");
		mainHeader.addToggleImage("upshrink", "/upshrink.gif", "/upshrink2.gif");
		mainHeader.addTogglePanel("upshrinkHeader");
		mainHeader.addTogglePanel("upshrinkHeader2");
	// ]]></script>';

	echo '
</head>
<body>';
}

function template_body_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	//start 1st table here;
	// table 1;
	echo '<table cellpadding="0" cellspacing="0" width="100%">
				  <tr>
						 <td>';
	//table 1.1;
	echo  '																	
								<table cellpadding="0" cellspacing="0"  class="logobg">
																										<tr>
																											 <td>';
	
	//Insert logo image!;
	echo '<img src="', $settings['images_url'], '/smflogo.jpg" style="margin-left: 20px;" title="', $context['forum_name'], ' " alt="Logo" />';

	//table 1.1 end;
	echo  '																			  
	</td></tr>
						</table>';																																			
	
	
	echo '			 
	</td>
  </tr><tr>';
	 
	 //begin navigation panel;
	 //table 1.2;
	 echo '			
	 <td><table cellpadding="0" cellspacing="0" class="menu_nav_panel_bg" width="100%"><tr><td>';
	 
	 //table 1.3; Insert Navigation menu;
	 echo '																										 
			<table cellpadding="0" cellspacing="0" class="menubg"><tr>';
	 
	 //[Site] , [Home] , [help] , [searh] buttons; Special thansk css-school.ru =\ ;
	 echo '<td id="home"><a href="', $scripturl, '?action=forum"><span>' ,$txt['home'], '</span></a></td>';
	 echo '<td id="help"><a href="', $scripturl, '?action=help"><span>' , $txt['help'] , '</span></a></td>';
	 if ($context['allow_search'])
	 echo '<td id="search"><a href="', $scripturl, '?action=search"><span>' , $txt['search'] , '</span></a></td>';
	 if ($context['allow_calendar'])
	 echo '<td id="calendar"><a href="', $scripturl, '?action=calendar"><span>' , $txt['calendar'] , '</span></a></td>';
	 
	 //Table 1.3 end; End menu; 
	 echo '						 
						</tr></table></td><td valign="top"><img src="', $settings['images_url'], '/menu_right.gif" alt="" /></td><td width="100%" align="right">';
	 
	 // Hello "%user";
	 if($context['user']['is_logged'])
		echo '

					<span class="hello_member"> ', $txt['hello_member_ndt'], ' <b><a href="', $scripturl, '?action=profile">', $context['user']['name'] , '</a></b>(<a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '">', $txt['logout'] , '</a>)</span>';
	 Else
	  {
	  echo '<span class="hello_member">';
	  echo sprintf($txt['welcome_guest'], $txt['guest_title']);
	  echo '</span>';
	  }
	 
	 //table 1.2 and 1 end;
	 echo '</td></tr></table></td></tr></table>';
															 
	//shadow
	echo '<table cellpadding="0" cellspacing="0" width="100%" class="shadow">
			 <tr>
				<td><img src="', $settings['images_url'], '/blank.gif" height="0" alt="" /></td>
			 </tr>
			</table>';															  
																	 
	

//user panel begin;
	 if($context['user']['is_logged'])
	 echo '<table cellpadding="10" cellspacing="0" width="100%" class="userpanel" border="0">';
	 Else
	 echo '<table cellpadding="10" cellspacing="0" width="100%" class="ghostpanel" border="0">';
	 echo		'<tr>
				<td style="font-family: Verdana; color: #212121; font-size: 12px;">';
	
	if($context['user']['is_logged'])
	{
	echo '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
							', $txt['totalTimeLogged1'];
							
							// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];

			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];

			// But, let's always show minutes - Time wasted here: 0 minutes ;).
			echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '';
							}
	else
	echo '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;', $txt['quick_login_dec'], '';
	echo '</td>';						
  
  //usermenu																		
	if($context['user']['is_logged'])
	{
	echo '<td class="usermenu">';
	if ($context['allow_admin'])
	echo '<a href="', $scripturl, '?action=admin">' , $txt['admin'] , '</a>';
	if ($context['user']['can_mod'])
  echo '<a href="', $scripturl, '?action=moderate">', $txt['moderate'], '</a>';
	if ($context['allow_edit_profile'])
	echo '<a href="', $scripturl, '?action=profile">' , $txt['profile'] , '</a>';
  echo '<a href="', $scripturl, '?action=mlist">', $txt['members_title'], '</a>';
  echo '<a href="', $scripturl, '?action=pm">', $txt['pm_short'], '';
  if ($context['user']['unread_messages'] > 0)
  echo ' (<strong>'. $context['user']['unread_messages'] . '</strong>)';
 
  echo '</a>';

  }
  Else
  echo '<td align="right"><form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" style="margin: 0;">
	<input type="text" name="user"  size="15" value="" style="background: #FFF url(', $settings['images_url'], '/login1.gif) right no-repeat; border: 1px solid #aaa;" alt="" />
	<input type="password" name="passwrd"  size="15"  value="" style="background: #FFF url(', $settings['images_url'], '/password.gif) right no-repeat; border: 1px solid #aaa;" alt=""  />&nbsp;
	', $txt['always_logged_in'], ':<input type="checkbox" name="cookieneverexp"  checked="checked" class="check" />
	<input type="submit" value="', $txt['login'], '" />
	</form>';
	echo '</td></tr></table><br />';
  
	// The main content should go here.
	echo '
	<div id="bodyarea" style="padding: 0px 20px 0 20px;">';  
}

function template_body_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
	</div>';

	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '

	<div id="footerarea" style="text-align: center; padding-bottom: 1ex;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">
		<table cellspacing="0" cellpadding="3" border="0" align="center" width="100%">
			<tr>
				<td valign="middle" align="center" style="white-space: nowrap;">
					', theme_copyright(), '
				</td>
			</tr>
			<tr><td align="center" style="font-size: 10px;">
			<a href="http://validator.w3.org/check/referer" target="_blank" title="valid XHTML"><span>XHTML</span></a>
			<a href="', $scripturl , '?type=rss;action=.xml"><span>RSS</span></a>
			<a href="', $scripturl , '?wap2"><span>WAP2</span></a>
			<br />
			<a href="http://smf2.uuuq.com">RuNet Theme by [cer]</a>
			</td></tr>
			</table>';
			

		// Show the load time?
	if ($context['show_load_time'])
		echo '
		<span class="smalltext">', $txt['page_created'], $context['load_time'], $txt['seconds_with'], $context['load_queries'], $txt['queries'], '</span>';

	echo '
	</div>';
}

function template_html_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	echo '<div class="nav" style="font-size: smaller; margin-bottom: 15px;">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;<img src="', $settings['images_url'], '/strela.gif" alt="" />&nbsp;';
	}

	echo '</div>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Are we using right-to-left orientation?
	if ($context['right_to_left'])
	{
		$first = 'last';
		$last = 'first';
	}
	else
	{
		$first = 'first';
		$last = 'last';
	}

	// Show the start of the tab section.
	echo '
			<table cellpadding="0" cellspacing="0" border="0" style="margin-left: 10px;">
				<tr>
					<td class="maintab_' , $first , '"></td>';

	foreach ($context['menu_buttons'] as $act => $button)
		echo ($button['active_button'] || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '				<td valign="top" class="maintab_', $button['active_button'] ? 'active_back' : 'back', '">
					<a href="', $button['href'], '">', $button['title'], '</a>
				</td>', $button['active_button'] ? '<td class="maintab_active_' . $last . '"></td>' : '';

	// The end of tab section.
	echo '
				<td class="maintab_' , $last , '">&nbsp;</td>
			</tr>
		</table>';

}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	// Create the buttons...
	foreach ($button_strip as $key => $value)
	{
		if (isset($value['test']) && empty($context[$value['test']]))
		{
			unset($button_strip[$key]);
			continue;
		}
		elseif (!isset($buttons[$key]) || $force_reset)
		{
			if ($value['url'] === '{SUBMIT}')
				$buttons[$key] = '<input type="submit" value="' . (isset($value['custom']) ? $value['custom'] : '') . $txt[$value['text']] . '" class="button_strip_submit" />';
			else
				$buttons[$key] = '<a href="' . $value['url'] . '" ' . (isset($value['custom']) ? $value['custom'] : '') . '>' . $txt[$value['text']] . '</a>';
		}
		$button_strip[$key] = $buttons[$key];
	}

	if (empty($button_strip))
		return '<td>&nbsp;</td>';

	echo '
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'last' : 'first' , '">&nbsp;</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_back">', implode(' &nbsp;|&nbsp; ', $button_strip) , '</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'first' : 'last' , '">&nbsp;</td>';
}

?>